# AGENTS

<skills_system priority="1">

<!-- SKILLS_TABLE_START -->
<usage>
Unified skill CLI tool. Use "magicskills skill-tool listskill --name Windsurf_skills" to find relevant skills.
Then use "magicskills skill-tool readskill --arg <path>" to read the selected skill's SKILL.md or related docs.
If needed, use "magicskills skill-tool execskill --arg <command>" to run the command.
</usage>
<!-- SKILLS_TABLE_END -->

</skills_system>
